<?php
/**
 * XML-RPC.
 *
 * @package Flat101\Security\Model\Block
 */

namespace Flat101\Security\Model\Block;

use Carbon_Fields\Field\Field;
use Flat101\Security\Model\Entity\Block;
use Flat101\Security\Model\Entity\Setting;

/**
 * XML-RPC class.
 */
class XmlRpcBlock extends Block {

	/**
	 * Block constructor.
	 */
	public function __construct() {
		parent::__construct(
			esc_html__( 'XML-RPC', 'flat101-security' ),
			'xmlrpc',
			array(
				new Setting( 'disabled', true, esc_html__( 'Disable XML-RPC', 'flat101-security' ) ),
			)
		);
	}

	// PHPDoc (inherited).
	// phpcs:ignore Squiz.Commenting.FunctionComment.Missing
	public function get_description() {

		$text = esc_html_x( 'this link', 'text for a HTML link', 'flat101-security' );
		$link = sprintf( '<a href="http://scripting.com/code/xmlrpcbrowserclient/index.html" target="_blank">%s</a>', $text );

		/* translators: %s: is a HTML link */
		return sprintf( esc_html__( 'You can use %s to check if XML-RPC is active on your site.', 'flat101-security' ), $link );
	}

	// PHPDoc (inherited).
	// phpcs:ignore Squiz.Commenting.FunctionComment.Missing
	public function get_fields() {
		return array(

			Field::make( 'checkbox', $this->get_option_name( 'disabled' ), $this->get_setting_label( 'disabled' ) )
			->set_default_value( $this->get_setting_default_value( 'disabled' ) )
			->set_help_text(
				__( 'Avoid DDoS and Brute Force attacks by disabling XML-RPC.', 'flat101-security' )
			),

		);
	}

	// PHPDoc (inherited).
	// phpcs:ignore Squiz.Commenting.FunctionComment.Missing
	public function run() {
		if ( $this->get_setting_value( 'disabled' ) ) {
			add_filter( 'xmlrpc_enabled', '__return_false' );
		}
	}
}
