<?php
/**
 * Utilities for activating a plugin.
 *
 * @package Flat101\Security\Util
 */

namespace Flat101\Security\Util;

/**
 * Useful class for activations.
 */
class ActivationUtil {

	/**
	 * Checks for a minimum PHP version and redirects the user (without activating the plugin) if necessary.
	 *
	 * @param string $script Path to plugin script.
	 * @param string $php_min_version For example '8.2.6'.
	 */
	public static function check_php_version( $script, $php_min_version ) {
		if ( version_compare( PHP_VERSION, $php_min_version, '<' ) ) {
			deactivate_plugins( basename( $script ) );
			wp_die(
				'<p>' .
				esc_html(
					sprintf(
					/* translators: %s: min PHP version */
						__( 'This plugin can not be activated because it requires PHP %s or newer.', 'flat101-security' ),
						$php_min_version
					)
				)
				. '</p>'
				. '<a href="' . esc_url( admin_url( 'plugins.php' ) ) . '">' . esc_html__( 'Go back', 'flat101-security' ) . '</a>'
			);
		}
	}


	/**
	 * Checks for a minimum WP version and redirects the user (without activating the plugin) if necessary.
	 *
	 * @param string $script Path to plugin script.
	 * @param string $wp_min_version For example '6.2.2'.
	 */
	public static function check_wp_version( $script, $wp_min_version ) {
		global $wp_version;

		if ( version_compare( $wp_version, $wp_min_version, '<' ) ) {
			deactivate_plugins( basename( $script ) );
			wp_die(
				'<p>' .
				esc_html(
					sprintf(
					/* translators: %s: min WordPress version */
						__(
							'This plugin can not be activated because it requires WordPress %s or newer. Please go to Dashboard &#9656; Updates to gran the latest version of WordPress.',
							'flat101-security'
						),
						$wp_min_version
					)
				)
				. '</p>'
				. '<a href="' . esc_url( admin_url( 'plugins.php' ) ) . '">' . esc_html__( 'Go back', 'flat101-security' ) . '</a>'
			);
		}
	}
}
