<?php
/**
 * Show messages to the user with WordPress style.
 *
 * @package Flat101\Security\Util
 */

namespace Flat101\Security\Util;

/**
 * Useful class to work with messages to the user.
 */
class WpNotice {

	/**
	 * Print the message to the user on the screen.
	 *
	 * @param string $style Valid values: 'info', 'success', 'warning', 'error'.
	 * @param string $str HTML Message.
	 */
	protected static function show( $style, $str ) {
		if ( ! empty( $str ) ) {
			echo wp_kses_post( '<div class="notice notice-' . $style . '"><p>' . $str . '</p></div>' );
		}
	}

	/**
	 * Print the info message.
	 *
	 * @param string $str HTML Message.
	 */
	public static function info( $str ) {
		static::show( 'info', $str );
	}

	/**
	 * Print the success message.
	 *
	 * @param string $str HTML Message.
	 */
	public static function success( $str ) {
		static::show( 'success', $str );
	}

	/**
	 * Print the warning message.
	 *
	 * @param string $str HTML Message.
	 */
	public static function warning( $str ) {
		static::show( 'warning', $str );
	}

	/**
	 * Print the error message.
	 *
	 * @param string $str HTML Message.
	 */
	public static function error( $str ) {
		static::show( 'error', $str );
	}
}
